## Ver. 1.6.3 - 2016-Dec-13

* Windows tests in [appveyor](https://ci.appveyor.com/project/lsbardel/pulsar)
* Select Event loop is the default in windows, ``proactor`` also available but with limited functionality
* Multiprocessing is default concurrency model (``process``) for both linux and windows
* Subprocess concurrency can be used in linux and windows with proactor event loop (``--concurrency subprocess``)
* Bug fix in ``stop_actors`` [e96cd13](https://github.com/quantmind/pulsar/commit/e96cd13e00b0afaefea18c95ee147d4a331a2c54)


## Ver. 1.6.2 - 2016-Nov-28

This release fixes a critical bug in windows (pulsar needs to choose how and if to officially support windows). 
It is now possible to install and run servers on windows (multiprocessing not working at the moment,
pass -w 0 when running servers).

* Critical bug fix for pulsar in ``windows`` [#260](https://github.com/quantmind/pulsar/issues/260)
* Check if **X-Forwarded-Proto** is available and equal to ``https`` in request headers to set the secure WSGI flag
* ``request.absolute_uri("")`` method with empty string returns the request uri
* Added logger property to request to allow to override the server logger


## Ver. 1.6.1 - 2016-Nov-24

Minor release with few improvements in the HTTPClient and ``Channels``

* ``HttpResponse.is_error`` is ``True`` when no status_code is available and the response is done
* ``HttpRequestException`` derives from ConnectionError
* Added query to request absolute_uri
* Channels improvements


## Ver. 1.6.0 - 2016-Nov-20

A new series with improvements in the HTTP client and server.
Broadly compatible with the 1.5 series with exception of headers definitions and actors
based on ``multiprocessing`` module (both have been removed because not used).
This version brings a **critical bug** fix for HTTP responses with non standard
values in body or content headers

* New ``is_message_complete`` method in ``HttpResponse``
* Critical bug fix for HTTP response with body when they should not have it.
  Disregard the body and content headers [#257](https://github.com/quantmind/pulsar/pull/257)
* If [http-request](https://github.com/benoitc/http-parser) module is installed, use its C parser as default HTTP parser.
  The python parser can still be used by passing ``--http-py-parser`` flag in the command line
* Removed headers definitions, no longer used [#222](https://github.com/quantmind/pulsar/issues/222)
* Removed actors based on ``multiprocessing`` module, not needed [a9cc662](https://github.com/quantmind/pulsar/commit/a9cc6623230ffc04c4ed0236ae33efb7bbb21060)
* Tests run with both python and C http-parser
* **Fully compatible with python 3.5 & 3.6**